.. highlight:: shell

==========
Instalacja
==========


Wersja stabilna
---------------

Aby zainstalować BPP, skorzystaj z dołączonych do kodu źródłowego skryptów
ansible. Przyjrzyj się na cel ``production`` w pliku ``Makefile`` znajdującym
się w głównym katalogu projektu. 

Ze źródeł
---------

Kod źródłowy projektu BPP możesz znaleźć w  `repozytorium GitHub`_.

Możesz sklonować kod z repozytorium publicznego:

.. code-block:: console

    $ git clone git://github.com/iplweb/bpp

Lub pobrać `archiwum tar`_:

.. code-block:: console

    $ curl  -OL https://github.com/iplweb/bpp/tarball/dev

.. _repozytorium GitHub: https://github.com/iplweb/bpp
.. _archiwum tar: https://github.com/iplweb/bpp/tarball/dev


Obraz maszyny wirtualnej
------------------------

Niekiedy udostępniane są obrazy maszyny wirtualnej w formacie OVA, zawierające
system operacyjny Linux z zainstalowanym oprogramowaniem Bibliografia Publikacji
Pracowników. Jeżeli chcesz dowiedzieć się więcej, zajrzyj na stronę
http://bpp.iplweb.pl/pobierz/ . Taki sposób uruchomienia oprogramowania
pozwala zapoznać się z jego możliwościami, jednakże nie polecamy stosowania
go w produkcji.
